/* ThemeRoller Sunny override style sheet for jQuery Calendars Picker v2.0.0. */
@import "ui.calendars.picker.css";

.ui-widget-header a,
.ui-widget-header select {
	color: #ffffff; /* Set (.ui-widget-header a) colour from theme here */
}
.ui-widget-header a:hover {
	background-color: #ffdd57; /* Set (.ui-state-hover) colours from theme here */
	color: #381f00;
}
.ui-widget-header select,
.ui-widget-header option {
	background-color: #817865; /* Set (.ui-widget-header) background colour from theme here */
}
.ui-state-highlight a {
	color: #1f1f1f; /* Set (.ui-state-highlight) colour from theme here */
}
